.. image:: ./logo/logo.svg
   :align: center

noise2read: turn noise to signal in short reads
===============================================

A novel machine-learning-based error correction algorithm noise2read follows the diversity of the PCR and sequencing process to clear errors in short reads, including DNA and RNA sequencing (DNA/RNA-seq), small RNA, unique molecular identifiers (UMI) and amplicon sequencing data.

Click `noise2read <https://noise2read.readthedocs.io/en/latest/>`__ to jump to noise2read documentation
=======================================================================================================
